# ATdataset
Audio text dataset for pytorch training based on webdataset.

## Install

```bash
pip install atdataset
```

## Build and upload

```bash
python -m pip install --upgrade build twine
python -m build
python -m twine upload dist/*
```
